/// <reference types="node" />
import { Server } from 'http';
import { Express } from 'express';
import { Logger } from 'winston';
import ExpressAppInterface from './ExpressAppInterface';
export type AsyncCallback<T> = (e: Express) => Promise<T>;
export interface ExpressAppConfig {
    port: number;
    onHealthCheck: AsyncCallback<boolean>;
    onLoading: AsyncCallback<void>;
    onReady: AsyncCallback<void>;
    onDestroy: AsyncCallback<void>;
    view?: {
        engine: string;
        path: string;
    };
}
export declare class ExpressApp implements ExpressAppInterface {
    private _app;
    private _server;
    private _routes;
    private _isReady;
    private _logger;
    private _appConfig;
    private _rootDir;
    get isReady(): boolean;
    get log(): Logger;
    get rootDir(): string;
    get express(): Express;
    get server(): Server;
    constructor(appConfig: ExpressAppConfig);
    private init;
    private initSecurityMiddlewares;
    start(): void;
    destroy(): Promise<void>;
}
